@@ -183,6 +183,7 @@ Miscellaneous assertions
 """
 
 import os
+import sys
 import math
 import inspect
 import reprlib
@@ -190,6 +191,7 @@ import builtins
 import textwrap
 import operator
 from types import MappingProxyType
+from inspect import Parameter
 from string import ascii_lowercase
 from typing import (Callable, Any, Type, Set, Optional, Mapping, Sequence, cast, Iterable,
                     FrozenSet, TypeVar)
@@ -198,6 +200,11 @@ from .ndrepr import aNDRepr
 from .functions import bind_callable, len_eq, str_eq, shape_eq, function_eq
 from .dataclass import AbstractDataClass, _MetaADC
 
+if sys.version_info <= (3, 6):
+    COMMA = ','
+else:
+    COMMA = ''
+
 __all__ = ['AssertionManager', 'assertion']
 
 T = TypeVar('T')
@@ -229,7 +236,7 @@ class _MetaAM(_MetaADC):
         len_eq, str_eq, shape_eq, function_eq
     })
 
-    def __new__(mcls, name, bases, namespace) -> '_MetaAM':
+    def __new__(mcls, name, bases, namespace) -> '_MetaAM':  # noqa: N804
         cls = cast('_MetaAM', super().__new__(mcls, name, bases, namespace))
 
         exclude = mcls.EXCLUDE
@@ -253,11 +260,11 @@ class _MetaAM(_MetaADC):
 
         # On windows os.path.isdir is an alias for the ._isdir function
         if os.name == 'nt':
-            cls.isdir = cls._isdir
-            cls.isdir.__name__ = 'isdir'
-            cls.isdir.__qualname__ = 'isdir'
-            cls.isdir.__doc__ = cls.isdir.__doc__.replace('_isdir', 'isdir')
-            del cls._isdir
+            cls.isdir = cls._isdir  # type: ignore
+            cls.isdir.__name__ = 'isdir'  # type: ignore
+            cls.isdir.__qualname__ = 'isdir'  # type: ignore
+            cls.isdir.__doc__ = cls.isdir.__doc__.replace('_isdir', 'isdir')  # type: ignore
+            del cls._isdir  # type: ignore
         return cls
 
 
@@ -349,7 +356,7 @@ class AssertionManager(AbstractDataClass, metaclass=_MetaAM):
 
         Parameters
         ----------
-        func : :data:`coollections.abc.Callable`
+        func : :class:`~collections.abc.Callable`
             The callable whose output will be evaluated.
 
         \*args : :data:`~typing.Any`
@@ -406,8 +413,12 @@ class AssertionManager(AbstractDataClass, metaclass=_MetaAM):
                 assert output, message
             else:
                 assert post_process(output), message
+
             if exception_ is not _NoneException:  # i.e. the exception parameter is not None
-                raise AssertionError(f"Failed to raise {exception_.__name__!r}")
+                message_ = f"Failed to raise {exception_.__name__!r}"
+                if message is not None:
+                    message_ += f'; {message}'
+                raise AssertionError(message_)
 
         except exception_:  # This is the expected exception
             pass  # Not relevant if the exception parameter is None
@@ -427,19 +438,22 @@ class AssertionManager(AbstractDataClass, metaclass=_MetaAM):
     def __call__(self, value: T, invert: bool = False,
                  post_process: Optional[Callable[[T], Any]] = None,
                  message: Optional[str] = None) -> None:
-        """Equivalent to :code:`assert value`.
+        f"""Equivalent to :code:`assert value`.
 
         Examples
         --------
         .. code:: python
 
-            >>> assertion = AssertionManager()
+            >>> from assertionlib import assertion
+
             >>> assertion(5 == 5)
             >>> assertion(5 == 6)
+            Traceback (most recent call last):
+              ...
             AssertionError: output = return_value(value); assert output
-
-            exception: AssertionError = AssertionError()
-
+            <BLANKLINE>
+            exception: AssertionError = AssertionError(None{COMMA})
+            <BLANKLINE>
             output: bool = False
             value: bool = False
 
@@ -448,10 +462,20 @@ class AssertionManager(AbstractDataClass, metaclass=_MetaAM):
 
         Parameters
         ----------
+        value : :data:`~typing.Any`
+            The to-be asserted value.
+
         invert : :class:`bool`
             If ``True``, invert the output of the assertion:
             :code:`assert not value`.
 
+        post_process : :class:`~collections.abc.Callable`, optional
+            Apply post-processing to the to-be asserted data before asserting aforementioned data.
+            Example functions would be the likes of :func:`~builtins.any` and :func:`~builtins.all`.
+
+        message : :data:`~typing.Any`, optional
+            A custom error message to-be passed to the ``assert`` statement.
+
 
         :rtype: :data:`None`
 
@@ -503,7 +527,7 @@ class AssertionManager(AbstractDataClass, metaclass=_MetaAM):
                          invert: bool = False, output: Any = None,
                          post_process: Optional[Callable[[T], Any]] = None,
                          **kwargs: Any) -> str:
-        r"""Return a formatted exception message for failed assertions.
+        f"""Return a formatted exception message for failed assertions.
 
         Examples
         --------
@@ -518,11 +542,13 @@ class AssertionManager(AbstractDataClass, metaclass=_MetaAM):
 
             >>> msg = assertion._get_exc_message(ex, func, a, b)
             >>> raise AssertionError(msg)
+            Traceback (most recent call last):
+              ...
             AssertionError: output = contains(a, b); assert output
-
-            exception: AssertionError = AssertionError()
-
-            output: bool = False
+            <BLANKLINE>
+            exception: TypeError = TypeError('Fancy custom exception'{COMMA})
+            <BLANKLINE>
+            output: NoneType = None
             a: list = [1, 2, 3, 4]
             b: int = 5
 
@@ -534,7 +560,7 @@ class AssertionManager(AbstractDataClass, metaclass=_MetaAM):
         func : :class:`~collections.abc.Callable`
             The callable whose output has been evaluated.
 
-        \*args : :data:`~typing.Any`
+        \\*args : :data:`~typing.Any`
             Positional arguments supplied to **func**.
 
         invert : :class:`bool`
@@ -547,7 +573,7 @@ class AssertionManager(AbstractDataClass, metaclass=_MetaAM):
             Apply post-processing to the to-be asserted data before asserting aforementioned data.
             Example functions would be the likes of :func:`~builtins.any` and :func:`~builtins.all`.
 
-        \**kwargs : :data:`~typing.Any`, optional
+        \\**kwargs : :data:`~typing.Any`, optional
             Further optional keyword arguments supplied to **func**.
 
         Returns
@@ -559,10 +585,7 @@ class AssertionManager(AbstractDataClass, metaclass=_MetaAM):
         __tracebackhide__ = True
 
         # Construct a string-reprensentation of the to-be assert function
-        try:
-            name = func.__qualname__
-        except AttributeError:  # Not all callables have the __qualname__ attribute
-            name = func.__name__
+        name: str = getattr(func, '__qualname__', func.__name__)
 
         # Construct a signature of the to-be asserted function
         try:
@@ -607,8 +630,7 @@ class AssertionManager(AbstractDataClass, metaclass=_MetaAM):
 
         """  # noqa
         # Unpack parameters
-        empty = inspect._empty
-        Parameter = inspect.Parameter
+        empty = inspect._empty  # type: ignore
         parameters = signature.parameters
         kind = Parameter.POSITIONAL_OR_KEYWORD
 
